@@ -9,6 +9,10 @@
 
 G_BEGIN_DECLS
 
+/* enumerations from "base-room-config.h" */
+GType tp_base_room_config_property_get_type (void) G_GNUC_CONST;
+#define TP_TYPE_BASE_ROOM_CONFIG_PROPERTY (tp_base_room_config_property_get_type ())
+
 /* enumerations from "connection-manager.h" */
 GType tp_cm_info_source_get_type (void) G_GNUC_CONST;
 #define TP_TYPE_CM_INFO_SOURCE (tp_cm_info_source_get_type ())
